.. _examples-index:

Examples
========

SkyPy implements models for the properties of various astrophysical objects and
a command-line script to run simulation pipelines. In the examples below we
demonstrate the usage of some of these models in both simple python scripts and
configuration files for more complex simulation pipelines.
